@@ -4,7 +4,8 @@ from cloudinary_cli.core.admin import admin
 from cloudinary_cli.core.config import config
 from cloudinary_cli.core.search import search
 from cloudinary_cli.core.uploader import uploader
-from cloudinary_cli.core.utils import url
+from cloudinary_cli.core.provisioning import provisioning
+from cloudinary_cli.core.utils import url, utils
 from cloudinary_cli.core.overrides import resolve_command
 
 setattr(click.MultiCommand, "resolve_command", resolve_command)
@@ -14,5 +15,7 @@ commands = [
     search,
     admin,
     uploader,
+    provisioning,
     url,
+    utils
 ]
