@@ -1,17 +1,17 @@
 import logging
 from os import path, makedirs
-from webbrowser import open as open_url
 
 import requests
-from click import style
+from click import style, launch
 from cloudinary import Search, uploader
 from cloudinary.utils import cloudinary_url
 
 from cloudinary_cli.defaults import logger
+from cloudinary_cli.utils.config_utils import is_valid_cloudinary_config
 from cloudinary_cli.utils.file_utils import normalize_file_extension, posix_rel_path
 from cloudinary_cli.utils.json_utils import print_json, write_json_to_file
-from cloudinary_cli.utils.utils import print_help, log_exception, confirm_action, \
-    get_command_params, merge_responses, normalize_list_params
+from cloudinary_cli.utils.utils import log_exception, confirm_action, get_command_params, merge_responses, \
+    normalize_list_params, ConfigurationError, print_api_help
 
 PAGINATION_MAX_RESULTS = 500
 
@@ -39,6 +39,7 @@ def query_cld_folder(folder):
                 "format": asset['format'],
                 "etag": asset.get('etag', '0'),
                 "relative_path": rel_path,  # save for inner use
+                "access_mode": asset.get('access_mode', 'public'),
             }
         # use := when switch to python 3.8
         next_cursor = res.get('next_cursor')
@@ -72,7 +73,10 @@ def download_file(remote_file, local_path, downloaded=None, failed=None):
     failed = failed if failed is not None else {}
     makedirs(path.dirname(local_path), exist_ok=True)
 
-    sign_url = True if remote_file['type'] in ("private", "authenticated") else False
+    if remote_file['type'] in ("private", "authenticated") or remote_file['access_mode'] == "authenticated":
+        sign_url = True
+    else:
+        sign_url = False
 
     download_url = cloudinary_url(asset_source(remote_file), resource_type=remote_file['resource_type'],
                                   type=remote_file['type'], sign_url=sign_url)[0]
@@ -118,7 +122,11 @@ def asset_source(asset_details):
 
 
 def call_api(func, args, kwargs):
-    return func(*args, **kwargs)
+    try:
+        return func(*args, **kwargs)
+    except Exception as e:
+        log_exception(e, f"Failed calling '{func.__name__}' with args: {args} and optional args {kwargs}")
+        raise
 
 
 def handle_command(
@@ -127,11 +135,13 @@ def handle_command(
         optional_parameter_parsed,
         module,
         module_name):
-    func, args, kwargs = get_command_params(params,
-                                            optional_parameter,
-                                            optional_parameter_parsed,
-                                            module,
-                                            module_name)
+    try:
+        func, args, kwargs = get_command_params(params, optional_parameter, optional_parameter_parsed, module,
+                                                module_name)
+    except Exception as e:
+        log_exception(e)
+        return False
+
     return call_api(func, args, kwargs)
 
 
@@ -152,19 +162,25 @@ def handle_api_command(
     Used by Admin and Upload API commands
     """
     if doc:
-        return open_url(doc_url)
+        return launch(doc_url)
 
     if ls or len(params) < 1:
-        return print_help(api_instance)
+        return print_api_help(api_instance)
 
-    func, args, kwargs = get_command_params(
-        params,
-        optional_parameter,
-        optional_parameter_parsed,
-        api_instance,
-        api_name)
+    try:
+        func, args, kwargs = get_command_params(params, optional_parameter, optional_parameter_parsed, api_instance,
+                                                api_name)
+    except Exception as e:
+        log_exception(e)
+        return False
 
-    res = call_api(func, args, kwargs)
+    if not is_valid_cloudinary_config():
+        raise ConfigurationError("No Cloudinary configuration found.")
+
+    try:
+        res = call_api(func, args, kwargs)
+    except Exception:
+        return False
 
     if auto_paginate:
         res = handle_auto_pagination(res, func, args, kwargs, force, filter_fields)
